summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJosh Soref <2119212+jsoref@users.noreply.github.com>2021-06-17 10:02:30 -0400
committerGitHub <noreply@github.com>2021-06-17 15:02:30 +0100
commitfd88b756fc20dedea15a8a08c21e8f7af6612e4e (patch)
tree81faaface4f605d329848b0c9b7dae8c7dad5b7f
parent8d1bc95faf095984dcc39b4c51de5bc5051b9a12 (diff)
Fix various spelling issues (#274).
Signed-off-by: Josh Soref <jsoref@users.noreply.github.com>.
-rw-r--r--cmake/Anope.cmake4
-rw-r--r--cmake/NSIS.template.in46
-rw-r--r--data/example.conf4
-rw-r--r--docs/CODING2
-rw-r--r--docs/Changes12
-rw-r--r--docs/Changes.conf4
-rw-r--r--docs/INSTALL2
-rw-r--r--docs/LANGUAGE4
-rw-r--r--docs/REDIS6
-rw-r--r--include/account.h12
-rw-r--r--include/anope.h22
-rw-r--r--include/channels.h4
-rw-r--r--include/commands.h8
-rw-r--r--include/config.h2
-rw-r--r--include/hashcomp.h2
-rw-r--r--include/language.h2
-rw-r--r--include/logger.h4
-rw-r--r--include/modes.h4
-rw-r--r--include/modules.h16
-rw-r--r--include/modules/httpd.h2
-rw-r--r--include/modules/ns_cert.h2
-rw-r--r--include/modules/pseudoclients/memoserv.h2
-rw-r--r--include/opertype.h2
-rw-r--r--include/protocol.h4
-rw-r--r--include/regchannel.h4
-rw-r--r--include/serialize.h6
-rw-r--r--include/servers.h2
-rw-r--r--include/users.h6
-rw-r--r--language/anope.en_US.po4
-rw-r--r--modules/CMakeLists.txt2
-rw-r--r--modules/commands/bs_kick.cpp2
-rw-r--r--modules/commands/ns_cert.cpp2
-rw-r--r--modules/commands/ns_group.cpp2
-rw-r--r--modules/database/db_old.cpp2
-rw-r--r--modules/encryption/enc_sha256.cpp4
-rw-r--r--modules/extra/m_mysql.cpp2
-rw-r--r--modules/protocol/plexus.cpp2
-rw-r--r--modules/pseudoclients/botserv.cpp2
-rw-r--r--modules/webcpanel/templates/default/chanserv/set.html2
-rw-r--r--src/hashcomp.cpp2
-rw-r--r--src/init.cpp2
-rw-r--r--src/misc.cpp14
-rw-r--r--src/modulemanager.cpp12
-rw-r--r--src/protocol.cpp2
-rw-r--r--src/sockets.cpp2
-rwxr-xr-xsrc/tools/geoipupdate.sh2
46 files changed, 126 insertions, 126 deletions
diff --git a/cmake/Anope.cmake b/cmake/Anope.cmake
index f93384cc0..44b4ea3ba 100644
--- a/cmake/Anope.cmake
+++ b/cmake/Anope.cmake
@@ -160,7 +160,7 @@ macro(sort_list LIST)
# For CMake 2.4.4 or better, this can be done automatically
list(SORT ${LIST})
else(CMAKE244_OR_BETTER)
- # For CMake 2.4.x before 2.4.4, we have to do this ourselves, firstly we'll create a teporary list
+ # For CMake 2.4.x before 2.4.4, we have to do this ourselves, firstly we'll create a temporary list
set(NEW_LIST)
# Iterate through the old list
foreach(ITEM ${${LIST}})
@@ -497,7 +497,7 @@ endmacro(calculate_libraries)
# check_functions(<source filename> <output variable set to TRUE on success>)
#
# This macro is used in most of the module (sub)directories to calculate the
-# fcuntion dependencies for the given source file.
+# function dependencies for the given source file.
###############################################################################
macro(check_functions SRC SUCCESS)
# Default to true
diff --git a/cmake/NSIS.template.in b/cmake/NSIS.template.in
index b40e82761..d2df95e74 100644
--- a/cmake/NSIS.template.in
+++ b/cmake/NSIS.template.in
@@ -348,7 +348,7 @@ Function un.RemoveFromPath
FunctionEnd
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-; Uninstall sutff
+; Uninstall stuff
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
###########################################
@@ -452,15 +452,15 @@ Done:
Exch $R1
FunctionEnd
-Function ConditionalAddToRegisty
+Function ConditionalAddToRegistry
Pop $0
Pop $1
- StrCmp "$0" "" ConditionalAddToRegisty_EmptyString
+ StrCmp "$0" "" ConditionalAddToRegistry_EmptyString
WriteRegStr SHCTX "Software\Microsoft\Windows\CurrentVersion\Uninstall\@CPACK_PACKAGE_NAME@" \
"$1" "$0"
;MessageBox MB_OK "Set Registry: '$1' to '$0'"
DetailPrint "Set install registry entry: '$1' to '$0'"
- ConditionalAddToRegisty_EmptyString:
+ ConditionalAddToRegistry_EmptyString:
FunctionEnd
;--------------------------------
@@ -558,44 +558,44 @@ Section "-Core installation"
WriteUninstaller "$INSTDIR\Uninstall.exe"
Push "DisplayName"
Push "@CPACK_NSIS_DISPLAY_NAME@"
- Call ConditionalAddToRegisty
+ Call ConditionalAddToRegistry
Push "DisplayVersion"
Push "@CPACK_PACKAGE_VERSION@"
- Call ConditionalAddToRegisty
+ Call ConditionalAddToRegistry
Push "Publisher"
Push "@CPACK_PACKAGE_VENDOR@"
- Call ConditionalAddToRegisty
+ Call ConditionalAddToRegistry
Push "UninstallString"
Push "$INSTDIR\Uninstall.exe"
- Call ConditionalAddToRegisty
+ Call ConditionalAddToRegistry
Push "NoRepair"
Push "1"
- Call ConditionalAddToRegisty
+ Call ConditionalAddToRegistry
!ifdef CPACK_NSIS_ADD_REMOVE
;Create add/remove functionality
Push "ModifyPath"
Push "$INSTDIR\AddRemove.exe"
- Call ConditionalAddToRegisty
+ Call ConditionalAddToRegistry
!else
Push "NoModify"
Push "1"
- Call ConditionalAddToRegisty
+ Call ConditionalAddToRegistry
!endif
; Optional registration
Push "DisplayIcon"
Push "$INSTDIR\@CPACK_NSIS_INSTALLED_ICON_NAME@"
- Call ConditionalAddToRegisty
+ Call ConditionalAddToRegistry
Push "HelpLink"
Push "@CPACK_NSIS_HELP_LINK@"
- Call ConditionalAddToRegisty
+ Call ConditionalAddToRegistry
Push "URLInfoAbout"
Push "@CPACK_NSIS_URL_INFO_ABOUT@"
- Call ConditionalAddToRegisty
+ Call ConditionalAddToRegistry
Push "Contact"
Push "@CPACK_NSIS_CONTACT@"
- Call ConditionalAddToRegisty
+ Call ConditionalAddToRegistry
!insertmacro MUI_STARTMENU_WRITE_BEGIN Application
;Create shortcuts
@@ -607,19 +607,19 @@ Section "-Core installation"
; Write special uninstall registry entries
Push "StartMenu"
Push "$STARTMENU_FOLDER"
- Call ConditionalAddToRegisty
+ Call ConditionalAddToRegistry
Push "DoNotAddToPath"
Push "$DO_NOT_ADD_TO_PATH"
- Call ConditionalAddToRegisty
+ Call ConditionalAddToRegistry
Push "AddToPathAllUsers"
Push "$ADD_TO_PATH_ALL_USERS"
- Call ConditionalAddToRegisty
+ Call ConditionalAddToRegistry
Push "AddToPathCurrentUser"
Push "$ADD_TO_PATH_CURRENT_USER"
- Call ConditionalAddToRegisty
+ Call ConditionalAddToRegistry
Push "InstallToDesktop"
Push "$INSTALL_DESKTOP"
- Call ConditionalAddToRegisty
+ Call ConditionalAddToRegistry
@CPACK_NSIS_EXTRA_INSTALL_COMMANDS@
@@ -739,7 +739,7 @@ Section "Uninstall"
@CPACK_NSIS_DELETE_ICONS@
@CPACK_NSIS_DELETE_ICONS_EXTRA@
- ;Delete empty start menu parent diretories
+ ;Delete empty start menu parent directories
StrCpy $MUI_TEMP "$SMPROGRAMS\$MUI_TEMP"
startMenuDeleteLoop:
@@ -752,13 +752,13 @@ Section "Uninstall"
StrCmp "$MUI_TEMP" "$SMPROGRAMS" startMenuDeleteLoopDone startMenuDeleteLoop
startMenuDeleteLoopDone:
- ; If the user changed the shortcut, then untinstall may not work. This should
+ ; If the user changed the shortcut, then uninstall may not work. This should
; try to fix it.
StrCpy $MUI_TEMP "$START_MENU"
Delete "$SMPROGRAMS\$MUI_TEMP\Uninstall.lnk"
@CPACK_NSIS_DELETE_ICONS_EXTRA@
- ;Delete empty start menu parent diretories
+ ;Delete empty start menu parent directories
StrCpy $MUI_TEMP "$SMPROGRAMS\$MUI_TEMP"
secondStartMenuDeleteLoop:
diff --git a/data/example.conf b/data/example.conf
index b25578d10..3e7efa942 100644
--- a/data/example.conf
+++ b/data/example.conf
@@ -710,7 +710,7 @@ log
* means "* ~operserv/*" would log everything because * matches everything.
*
* Valid admin, override, and command options are:
- * pesudo-serv/commandname (e.g. operserv/akill, chanserv/set)
+ * pseudo-serv/commandname (e.g. operserv/akill, chanserv/set)
*
* Valid server options are:
* connect, quit, sync, squit
@@ -1155,7 +1155,7 @@ module
* db_sql module allows saving and loading databases using one of the SQL engines.
* This module loads the databases once on startup, then incrementally updates
* objects in the database as they are changed within Anope in real time. Changes
- * to the SQL tables not done by Anope will have no effect and will be overwritten.
+ * to the SQL tables not done by Anope will have no effect and will be overwriten.
*
* db_sql_live module allows saving and loading databases using one of the SQL engines.
* This module reads and writes to SQL in real time. Changes to the SQL tables
diff --git a/docs/CODING b/docs/CODING
index 31fa4e847..6c56d0ddf 100644
--- a/docs/CODING
+++ b/docs/CODING
@@ -59,7 +59,7 @@ yet follows these. This will be rectified with time.
4. Braces
Always put braces opening and closing blocks on separate lines, see the
- identation example. For example, place braces like this:
+ indentation example. For example, place braces like this:
if (apples == "green")
{
cout << "Apples are green" << endl;
diff --git a/docs/Changes b/docs/Changes
index 67674e156..4d4f25b4f 100644
--- a/docs/Changes
+++ b/docs/Changes
@@ -83,7 +83,7 @@ Fix chankill to not add duplicate akills
Allow nickserv/maxemail to disregard gmail style aliases when comparing emails
Fix chanserv/mode when setting listmodes with CIDR ranges
Fix reported expiry time when the time is divisible by 1 year
-Clearify botserv repeat kicker help and allow setting repeat times to 1
+Clarify botserv repeat kicker help and allow setting repeat times to 1
Send vident/vhost with SASL login
Add support for SASL reauth
Fix log and database backup directories to be properly created by the installer
@@ -255,7 +255,7 @@ Anope Version 1.9.3
A Added italics BotServ kicks support
A Tell users when their nicks expire in /ns glist and /ns info
A Added SSL support
-A Prevent negaitve mode changes, kicks, bans, and autokicks from affecting people with the 'god' user mode (On UnrealIRCd, usermode +q)
+A Prevent negative mode changes, kicks, bans, and autokicks from affecting people with the 'god' user mode (On UnrealIRCd, usermode +q)
A Added nickserv/auxpex permission
A Added nickserv ungroup command
A Renamed the SGLINE to be SNLINE
@@ -267,15 +267,15 @@ A Added m_mysql which uses threads to execute queries
A Added many subcommand modules for some commands, eg ns_set_autoop, ns_set_email, etc
A Added a new logging system that is a bit more flexible
A Added cs_set_misc and ns_set_misc to add miscellaneous set commands
-A Added os_modreload, which allows reloading some modules not normally unloable, like the protocol module
+A Added os_modreload, which allows reloading some modules not normally unloadable, like the protocol module
A Added FOUNDER access level
A Made OperServ, Global, MemoServ, and ChanServ optional
F Shutting down if a config reload fails
F Autoid to live through restarts on Unreal
F Storing vhosts in MySQL
-F Not flushing the anope_extra table before rewriting databaes
+F Not flushing the anope_extra table before rewriting database
F Anoperc start/stop to send the globaloncycle global, and fixed anoperc rehash to really rehash
-F Fixed a potential crash if HostServ or BotServ was disbled
+F Fixed a potential crash if HostServ or BotServ was disabled
Anope Version 1.9.2
-------------------
@@ -299,7 +299,7 @@ F Unban command to accept an optional nick arg
F Some typos in services.conf
F Crash when users change their host that are identified to a group, but not a nick
F Host length checking in HS SET(ALL) and HS REQUEST
-F Only show if a user is online in NS INFO if they are really identiifed for the group of the nick they are on
+F Only show if a user is online in NS INFO if they are really identified for the group of the nick they are on
F Crash when using BSSmartJoin
F Converting access entries to access from xop when a users access is below voice
F A bad pointer passed to the OnDelEvent which could cause some 3rd party modules to crash
diff --git a/docs/Changes.conf b/docs/Changes.conf
index 662829ca3..0765d6b66 100644
--- a/docs/Changes.conf
+++ b/docs/Changes.conf
@@ -63,7 +63,7 @@ mail:restrict removed
Anope Version 1.9.9
-------------------
-There is not many config changes betewen 1.9.8 and 1.9.9, however many of the
+There is not many config changes between 1.9.8 and 1.9.9, however many of the
options have been moved around to make more sense, too many to list here,
so get a new config.
@@ -164,7 +164,7 @@ options:enablelogchannel added to auto turn on the logchannel on startup
options:mlock added to configure the default mlock modes on new channels
options:database added for the database modules
options:botmodes added to configure modes BotServ bots should use
-options:userlen added to configure maxiumum ident length
+options:userlen added to configure maximum ident length
options:hostlen added to configure maximum hostname length
options:database added to configure what database modules to use
options:passlen added to specify the maximum length of passwords
diff --git a/docs/INSTALL b/docs/INSTALL
index 21ca16e19..1ad9533cb 100644
--- a/docs/INSTALL
+++ b/docs/INSTALL
@@ -80,7 +80,7 @@ Note: You should also read the README and FAQ files!
The configuration varies depending on the IRCd, but you will probably need
a link block (also called connect block, or C line), a U line (also called
- a shared block), and be sure that the IRCd is listneing on the given port
+ a shared block), and be sure that the IRCd is listening on the given port
in the link block.
Example link configurations can be found in example.conf for some of the
diff --git a/docs/LANGUAGE b/docs/LANGUAGE
index bf7317864..b2e72cc9a 100644
--- a/docs/LANGUAGE
+++ b/docs/LANGUAGE
@@ -1,4 +1,4 @@
-Anope Mutli Language Support
+Anope Multi Language Support
----------------------------
1) Building Anope with gettext support
@@ -36,7 +36,7 @@ Anope Mutli Language Support
NOTE: There is no guarantee we will use your work so please do not be offended if we say no thanks.
-3) Using langages with modules
+3) Using languages with modules
Module authors can easily add the ability to have their modules translated by adding _() around the strings they
want translated (messages to the user, etc).
diff --git a/docs/REDIS b/docs/REDIS
index d18585979..8f7a076fd 100644
--- a/docs/REDIS
+++ b/docs/REDIS
@@ -32,7 +32,7 @@ Table of Contents
hash - The keys in hash are the actual objects, stored as hashes. For
example, if I had just looked up all BotInfo ids and wanted to iterate
- over all of them, I woulld start by:
+ over all of them, I would start by:
redis 127.0.0.1:6379> HGETALL hash:BotInfo:1
@@ -73,7 +73,7 @@ Table of Contents
(https://redis.io/topics/notifications). This allows Redis to notify Anope of
any external changes to objects in the database. Once notified, Anope will
immediately update the object. Otherwise, Anope keeps all objects in memory
- and will not regularly read from the databaes once started.
+ and will not regularly read from the database once started.
You can use this to modify objects in Redis and have them immediately reflected
back into Anope. Additionally you can use this feature to run multiple Anope
@@ -93,7 +93,7 @@ Table of Contents
The key space ids and value are managed entirely by Anope, you do
not (and should not) modify them. Once you modify the object (hash), Anope will
- update them for you to correctly refelect any changes made to the object.
+ update them for you to correctly reflect any changes made to the object.
Finally, always use atomic operations. If you are inserting a new object with
multiple commands, or inserting multiple objects at once, specifically if the
diff --git a/include/account.h b/include/account.h
index d4b255c29..1a6809d90 100644
--- a/include/account.h
+++ b/include/account.h
@@ -61,7 +61,7 @@ class CoreExport NickAlias : public Serializable, public Extensible
* @param ident The ident
* @param host The host
* @param creator Who created the vhost
- * @param time When the vhost was craated
+ * @param time When the vhost was created
*/
void SetVhost(const Anope::string &ident, const Anope::string &host, const Anope::string &creator, time_t created = Anope::CurTime);
@@ -130,7 +130,7 @@ class CoreExport NickCore : public Serializable, public Extensible
*/
Serialize::Checker<std::vector<NickAlias *> > aliases;
- /* Set if this user is a services operattor. o->ot must exist. */
+ /* Set if this user is a services operator. o->ot must exist. */
Oper *o;
/* Unsaved data */
@@ -234,7 +234,7 @@ class CoreExport NickCore : public Serializable, public Extensible
class CoreExport IdentifyRequest
{
/* Owner of this request, used to cleanup requests if a module is unloaded
- * while a reqyest us pending */
+ * while a request us pending */
Module *owner;
Anope::string account;
Anope::string password;
@@ -262,17 +262,17 @@ class CoreExport IdentifyRequest
* for the request to complete. Multiple modules may hold a request at any time,
* but the request is not complete until every module has released it. If you do not
* require holding this (eg, your password check is done in this thread and immediately)
- * then you don't need to hold the request before Successing it.
+ * then you don't need to hold the request before calling `Success()`.
* @param m The module holding this request
*/
void Hold(Module *m);
/** Releases a held request
- * @param m The module releaseing the hold
+ * @param m The module releasing the hold
*/
void Release(Module *m);
- /** Called by modules when this IdentifyRequest has successeded successfully.
+ /** Called by modules when this IdentifyRequest has succeeded.
* If this request is behind held it must still be Released after calling this.
* @param m The module confirming authentication
*/
diff --git a/include/channels.h b/include/channels.h
index 2d9b848d8..838dd15c0 100644
--- a/include/channels.h
+++ b/include/channels.h
@@ -232,7 +232,7 @@ class CoreExport Channel : public Base, public Extensible
* @param bi The sender, can be NULL for the service bot for this channel
* @param u The user being kicked
* @param reason The reason for the kick
- * @return true if the kick was scucessful, false if a module blocked the kick
+ * @return true if the kick was successful, false if a module blocked the kick
*/
bool Kick(BotInfo *bi, User *u, const char *reason = NULL, ...);
@@ -249,7 +249,7 @@ class CoreExport Channel : public Base, public Extensible
/** Get a string of the modes set on this channel
* @param complete Include mode parameters
- * @param plus If set to false (with complete), mode parameters will not be given for modes requring no parameters to be unset
+ * @param plus If set to false (with complete), mode parameters will not be given for modes requiring no parameters to be unset
* @return A mode string
*/
Anope::string GetModes(bool complete, bool plus);
diff --git a/include/commands.h b/include/commands.h
index 5f41d68e9..64335720f 100644
--- a/include/commands.h
+++ b/include/commands.h
@@ -40,7 +40,7 @@ struct CommandInfo
bool prepend_channel;
};
-/* Where the replies from commands go to. User inheits from this and is the normal
+/* Where the replies from commands go to. User inherits from this and is the normal
* source of a CommandReply
*/
struct CoreExport CommandReply
@@ -101,7 +101,7 @@ class CoreExport Command : public Service
bool require_user;
public:
- /* Maximum paramaters accepted by this command */
+ /* Maximum parameters accepted by this command */
size_t max_params;
/* Minimum parameters required to use this command */
size_t min_params;
@@ -148,7 +148,7 @@ class CoreExport Command : public Service
*/
virtual void Execute(CommandSource &source, const std::vector<Anope::string> &params) = 0;
- /** Called when HELP is requsted for the client this command is on.
+ /** Called when HELP is requested for the client this command is on.
* @param source The source
*/
virtual void OnServHelp(CommandSource &source);
@@ -178,7 +178,7 @@ class CoreExport Command : public Service
* Note that if the same command exists multiple places this will return the first one encountered
* @param command_service The command service to lookup, eg, nickserv/register
* @param bot If found, is set to the bot the command is on, eg NickServ
- * @param name If found, is set to the comand name, eg REGISTER
+ * @param name If found, is set to the command name, eg REGISTER
* @return true if the given command service exists
*/
static bool FindCommandFromService(const Anope::string &command_service, BotInfo* &bi, Anope::string &name);
diff --git a/include/config.h b/include/config.h
index e02cf0157..d8ef07695 100644
--- a/include/config.h
+++ b/include/config.h
@@ -165,7 +165,7 @@ namespace Configuration
class ConfigException : public CoreException
{
public:
- /** Default constructor, just uses the error mesage 'Config threw an exception'.
+ /** Default constructor, just uses the error message 'Config threw an exception'.
*/
ConfigException() : CoreException("Config threw an exception", "Config Parser") { }
/** This constructor can be used to specify an error message before throwing.
diff --git a/include/hashcomp.h b/include/hashcomp.h
index ed1937842..983115620 100644
--- a/include/hashcomp.h
+++ b/include/hashcomp.h
@@ -26,7 +26,7 @@ namespace Anope
{
class string;
- /* Casemap in use by Anope. ci::string's comparation functions use this (and thus Anope::string) */
+ /* Casemap in use by Anope. ci::string's comparison functions use this (and thus Anope::string) */
extern std::locale casemap;
extern void CaseMapRebuild();
diff --git a/include/language.h b/include/language.h
index dfaf7140e..49617a4c5 100644
--- a/include/language.h
+++ b/include/language.h
@@ -40,7 +40,7 @@ namespace Language
extern CoreExport const char *Translate(const char *string);
/** Translates a string to the language of the given user.
- * @param u The user to transate the string for
+ * @param u The user to translate the string for
* @param string A string to translate
* @return The translated
diff --git a/include/anope.h b/include/anope.h
index 4f24a5681..fe2b96a42 100644
--- a/include/anope.h
+++ b/include/anope.h
@@ -362,7 +362,7 @@ namespace Anope
*/
extern CoreExport int Debug;
- /** Other comand line options.
+ /** Other command line options.
*/
extern CoreExport bool ReadOnly, NoFork, NoThird, NoExpire, ProtocolDebug;
@@ -403,7 +403,7 @@ namespace Anope
/** Used to "fork" the process and go into the background during initial startup
* while we are AtTerm(). The actual fork is not done here, but earlier, and this
- * simply notifys the parent via kill() to exit().
+ * simply notifies the parent via kill() to exit().
*/
extern void Fork();
@@ -413,7 +413,7 @@ namespace Anope
/** One of the first functions called, does general initialization such as reading
* command line args, loading the configuration, doing the initial fork() if necessary,
- * initializating language support, loading modules, and loading databases.
+ * initializing language support, loading modules, and loading databases.
* @throws CoreException if something bad went wrong
*/
extern void Init(int ac, char **av);
@@ -574,7 +574,7 @@ class CoreExport sepstream
public:
/** Create a sepstream and fill it with the provided data
*/
- sepstream(const Anope::string &source, char seperator, bool allowempty = false);
+ sepstream(const Anope::string &source, char separator, bool allowempty = false);
/** Fetch the next token from the stream
* @param token The next token from the stream is placed here
@@ -584,7 +584,7 @@ class CoreExport sepstream
/** Gets token number 'num' from the stream
* @param token The token is placed here
- * @param num The token number to featch
+ * @param num The token number to fetch
* @return True if the token was able to be fetched
*/
bool GetToken(Anope::string &token, int num);
@@ -602,7 +602,7 @@ class CoreExport sepstream
/** Gets token number 'num' from the stream and all remaining tokens.
* @param token The token is placed here
- * @param num The token number to featch
+ * @param num The token number to fetch
* @return True if the token was able to be fetched
*/
bool GetTokenRemainder(Anope::string &token, int num);
@@ -628,7 +628,7 @@ class CoreExport sepstream
class commasepstream : public sepstream
{
public:
/** Initialize with comma seperator
*/
commasepstream(const Anope::string &source, bool allowempty = false) : sepstream(source, ',', allowempty) { }
};
@@ -638,7 +638,7 @@ class commasepstream : public sepstream
class spacesepstream : public sepstream
{
public:
/** Initialize with space seperator
*/
spacesepstream(const Anope::string &source) : sepstream(source, ' ') { }
};
@@ -659,7 +659,7 @@ class CoreException : public std::exception
*/
Anope::string source;
public:
- /** Default constructor, just uses the error mesage 'Core threw an exception'.
+ /** Default constructor, just uses the error message 'Core threw an exception'.
*/
CoreException() : err("Core threw an exception"), source("The core") { }
/** This constructor can be used to specify an error message before throwing.
@@ -691,7 +691,7 @@ class CoreException : public std::exception
class ModuleException : public CoreException
{
public:
- /** Default constructor, just uses the error mesage 'Module threw an exception'.
+ /** Default constructor, just uses the error message 'Module threw an exception'.
*/
ModuleException() : CoreException("Module threw an exception", "A Module") { }
@@ -766,7 +766,7 @@ template<typename T> inline T convertTo(const Anope::string &s, bool failIfLefto
}
/** Casts to be used instead of dynamic_cast, this uses dynamic_cast
- * for debug builds and static_cast on releass builds
+ * for debug builds and static_cast on release builds
* to speed up the program because dynamic_cast relies on RTTI.
*/
#ifdef DEBUG_BUILD
@@ -628,7 +628,7 @@ class CoreExport sepstream
{
public:
- /** Initialize with comma seperator
+ /** Initialize with comma separator
*/
commasepstream(const Anope::string &source, bool allowempty = false) : sepstream(source, ',', allowempty) { }
@@ -638,7 +638,7 @@ class commasepstream : public sepstream
{
public:
- /** Initialize with space seperator
+ /** Initialize with space separator
*/
spacesepstream(const Anope::string &source) : sepstream(source, ' ') { }